@@ -8,24 +8,20 @@ use Module::CoreList 2.99;
 use Module::Version 'get_version';
 use autodie;
 use Moose;
-use IPC::Cmd qw[can_run run];
-use Dependencies::Searcher::AckRequester;
-use Log::Minimal env_debug => 'LM_DEBUG';
-use File::Stamped;
-use IO::File;
+use IO::File;  # This comment creates a bug
 use File::HomeDir;
 use File::Spec::Functions qw(catdir catfile);
 use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
+use File::Next;
 
-our $VERSION = '0.066_001';
+our $VERSION = '0.066_002';
 
 =head1 NAME
 
 Dependencies::Searcher - Search for modules used or required by a
-distribution and build a report that can be used as L<Carton|Carton>
-cpanfile .
+distribution.
 
 =cut
 
@@ -64,7 +60,7 @@ cpanfile .
     my $cmd_use = $requester->build_cmd(@params);
 
     # Execute the command and retrieve the output
-    my @moduls = $requester->ack($cmd_use);
+    my @moduls = $requester->search($cmd_use);
 
 =cut
 
@@ -141,58 +137,20 @@ has 'full_path' => (
   isa => 'Str',
 );
 
-# Log stuff here
-$ENV{LM_DEBUG} = 1; # 1 for debug logs, 0 for info
-
-my $work_path = File::HomeDir->my_data;
-my $log_fh = File::Stamped->new(
-    pattern => catdir($work_path,  "dependencies-searcher.log.%Y-%m-%d.out"),
-);
-
-say("tail -vf $work_path for log");
-
-# Overrides Log::Minimal PRINT
-$Log::Minimal::PRINT = sub {
-    my ( $time, $type, $message, $trace) = @_;
-    print {$log_fh} "$time [$type] $message\n";
-};
-
-infof("Dependencies::Searcher $VERSION debugger init.");
-infof("Log file available in " . $work_path);
-# End of log init
 
 sub get_modules {
     # @path contains files and directories
     my ($self, $pattern, @path) = @_;
 
-    debugf("Ack pattern : " . $pattern);
+    say("Ack pattern : " . $pattern);
 
-    # The regex add the terminal semicolon at the end of the line to
-    # make the difference between comments and code, because "use" is
-    # a word that you can find often in a POD section, more much in
-    # the beginning of line than you could think
-    $pattern = "$pattern" . qr/.+;$/;
-
-    my @params = ('--perl', '-hi', $pattern, @path);
-    foreach my $param (@params) {
-	debugf("Param : " . $param);
-    }
-
-    my $requester = Dependencies::Searcher::AckRequester->new();
-
-    my $ack_path = $requester->get_path();
-    debugf("Ack path : " . $ack_path);
-
-    my $cmd_use = $requester->build_cmd(@params);
-
-    my @moduls = $requester->ack($cmd_use);
-    infof("Found $pattern modules : " . @moduls);
+    my @moduls = $self->search($pattern, @path);
+    say("Found $pattern modules : " . @moduls);
 
     if ( defined $moduls[0]) {
 	if ($moduls[0] =~ m/^use/ or $moduls[0] =~ m/^require/) {
 	    return @moduls;
 	} else {
-	    critf("Failed to retrieve modules with Ack");
 	    die "Failed to retrieve modules with Ack";
 	}
     } else {
@@ -206,6 +164,7 @@ sub get_files {
     my $lib_dir = dir('lib');
     my $make_file = file('Makefile.PL');
     my $script_dir = dir('script');
+    # note t/ is ignored
 
     my @structure;
     $structure[0] = "";
@@ -236,7 +195,7 @@ sub get_files {
 sub merge_dependencies {
     my ($self, @uses, @requires) = @_;
     my @merged_dependencies = (@uses, @requires);
-    infof("Merged use and require dependencies");
+    say("Merged use and require dependencies");
     return @merged_dependencies;
 }
 
@@ -268,7 +227,7 @@ sub clean_everything {
 
     foreach my $module ( @dirty_modules ) {
 
-	debugf("Dirty module : " . $module);
+	say("Dirty module : " . $module);
 
 	# remove the 'use' and the space next
 	$module =~ s{
@@ -378,7 +337,7 @@ sub clean_everything {
 		}
 		    {}xi;
 
-	debugf("Clean module : " . $module);
+	say("Clean module : " . $module);
 	push @clean_modules, $module;
     }
     return @clean_modules;
@@ -391,7 +350,7 @@ sub uniq {
     my %seen = ();
     foreach my $element ( @many_modules ) {
 	next if $seen{ $element }++;
-	debugf("Uniq element added : " . $element);
+	say("Uniq element added : " . $element);
 	push @unique_modules, $element;
     }
     return @unique_modules;
@@ -422,8 +381,8 @@ sub dissociate {
 	    # Return the corelist version
 	    my $corelist_version = $Module::CoreList::version{ $] }{"$nc_module"};
 
-	    debugf("Mversion version : " . $mversion_version);
-	    debugf("Corelist version : " . $corelist_version);
+	    say("Mversion version : " . $mversion_version);
+	    say("Corelist version : " . $corelist_version);
 
 	    # Version::Compare warns about versions numbers with '_'
 	    # are 'non-numeric values'
@@ -437,14 +396,14 @@ sub dissociate {
 	    if (&Version::Compare::version_compare(
 		$mversion_version, $corelist_version
 	    ) == 1) {
-		infof(
+		say(
 		    $nc_module . " version " . $mversion_version .
 		    " is in use but  " .
 		    $corelist_version .
 		    " is in core list"
 		);
 		$self->add_non_core_module($nc_module);
-		infof(
+		say(
 		    $nc_module .
 		    " is in core but has been added to non core " .
 		    "because it's a fresh core"
@@ -462,11 +421,11 @@ sub dissociate {
 	    # The "Moose" trait way
 	    # http://metacpan.org/module/Moose::Meta::Attribute::Native::Trait::Array
 	    $self->add_core_module($nc_module);
-	    infof($nc_module . " is core");
+	    say($nc_module . " is core");
 
 	} else {
 	    $self->add_non_core_module($nc_module);
-	    infof($nc_module . " is not in core");
+	    say($nc_module . " is not in core");
 	    # push @{ $self->non_core_modules }, $nc_module;
 	}
     }
@@ -491,7 +450,7 @@ sub generate_report {
 
 	# if not undef
 	if ($version) {
-	    debugf("Module + version : " . $module_name . " " . $version);
+	    say("Module + version : " . $module_name . " " . $version);
 
 	    # Add the "requires $module_name\n" to the next line of the file
 	    chomp($module_name, $version);
@@ -501,69 +460,116 @@ sub generate_report {
 	    } # else : other case ?
 
 	} else {
-	    debugf("Module + version : " . $module_name);
+	    say("Module + version : " . $module_name);
 	    say $cpanfile_fh "requires '$module_name';";
 	}
 
     }
 
     close $cpanfile_fh;
-    infof("File has been generated and is waiting for you");
+    say("File has been generated and is waiting for you");
 }
 
-# From Dependencies::Searcher::AckRequester, DEPRECATED
-sub get_path {
-    my $self = shift;
+# DEPRECATED
+# sub build_cmd {
 
-    my $tmp_full_path = can_run('ack');
+#     my ($self, @params) = @_;
 
-    if ($tmp_full_path) {
-	$self->full_path($tmp_full_path);
-	debugf("Ack full path : " . $self->full_path);
-	return $self->full_path;
-    } else {
-	critf('Something goes wrong with Ack path or IPC::Run is not available !');
-    }
-}
+#     my @cmd = ($self->full_path, @params);
+#     my $cmd_href = \@cmd;
+
+#     return $cmd_href;
+# }
 
 
-sub build_cmd {
 
-    my ($self, @params) = @_;
-
-    my @cmd = ($self->full_path, @params);
-    my $cmd_href = \@cmd;
-
-    return $cmd_href;
-}
-
-# From Dependencies::Searcher::AckRequester, DEPRECATED
-# Maybe this is not very clean, but it works
-sub ack {
-    my ($self, $cmd) = @_;
-
-    my (
-	$success,
-	$error_message,
-	$full_buffer,
-	$stdout_buffer,
-	$stderr_buffer
-    ) = run (
-	command => $cmd,
-	verbose => 0
-    );
+# under rewriting
+sub search {
+    my ($self, $pattern, @paths) = @_;
 
     my @modules;
 
-    debugf("All modules in distribution : " . join "", @$full_buffer);
+    my $iter = File::Next::files(@paths);
 
-    if ($success) {
-	push @modules, split(/\n/m, $$full_buffer[0]);
-    } else {
-	say "No module have been found or IPC::Cmd failed with error $error_message";
+    # Each path is a file in the chosen hierarchy
+    while ( defined ( my $path = $iter->() )) {
+        say($path);
+        my $file = file($path);
+        my @lines = $file->slurp;
+        for my $line (@lines) {
+            # Remove carriage return
+            chomp  $line;
+            # Remove tabs
+            $line =~ s/^\t+//;
+            if ($line =~ /^$pattern\s/ ) {
+                say($line);
+
+                # Clean the result
+                $line = $self->rm_comments($line);
+
+                push(@modules, $line);
+            }
+        }
     }
 
+    p @modules;
     return @modules;
+
+    # old code
+
+    # my (
+    #     $success,
+    #     $error_message,
+    #     $full_buffer,
+    #     $stdout_buffer,
+    #     $stderr_buffer
+    # ) = run (
+    #     command => $cmd,
+    #     verbose => 0
+    # );
+
+    # my @modules;
+
+    # say("All modules in distribution : " . join "", @$full_buffer);
+
+    # if ($success) {
+    #     push @modules, split(/\n/m, $$full_buffer[0]);
+    # } else {
+    #     say "No module have been found or IPC::Cmd failed with error $error_message";
+    # }
+
+    # return @modules;
+}
+
+# It could be a simplist implementation, but I didn't find something
+# more clever. Comments appreciated.
+sub rm_comments {
+
+    my ($self, $dirt) = @_;
+
+    say("Inside rm with $dirt");
+
+    # Case #1: "use" declaration line with a comment after
+    # The regex add the terminal semicolon at the end of the line to
+    # make the difference between comments and code, because "use" is
+    # a word that you can find often in a POD section, more much in
+    # the beginning of line than you could think
+    if ( $dirt =~ /#.+/ ) {
+        say("ENTER IT for $dirt");
+        $dirt =~ s/#(.*)//;
+    }
+
+    # $pattern = "$pattern" . qr/.+;$/; # <= This is an horrible bug,
+                                      #    because we could have a
+                                      #    comment here
+
+    # Case #2 pod
+    # TODO
+
+
+    my $clean = $dirt;
+
+    return $clean;
 }
 
 
@@ -723,34 +729,12 @@ crap inside too.
 
 =cut
 
+=head2 rm_comments($line_that_should_be_cleaned_of_any_comment)
 
-=head2 Log::Minimal::PRINT override
-
-Just override the way Log::Minimal is used. See LOGGING AND DEBUGGING
-for more informations.
+Supposed to remove any comment from a line.
 
 =cut
 
-=head1 LOGGING AND DEBUGGING
-
-This module has a very convenient logging system that use
-L<Log::Minimal|Log::Minimal> and L<File::Stamped|File::Stamped> to
-write to a file that you will find in the directory where local
-applications should store their internal data for the current
-user. This is totally portable (Thanks to Nikolay Mishin
-(mishin)). For exemple, on a Debian-like OS :
-
-    ~/.local/share/dependencies-searcher.[y-M-d].out
-
-To debug and use these logs :
-
-    $ tail -vf ~/local/share/dependencies-searcher.[y-M-d].out
-
-For more information on how to configure log level, read
-L<Log::Minimal|Log::Minimal> documentation.
-
-For a simple exemple on how to use it, see this blog post http://bit.ly/1lJwyX7
-
 =head1 CAVEATS
 
 =head2 Low Win32 / Cygwin support
@@ -787,6 +771,10 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dependencies-Searcher>.
 I will be notified, and then you'll automatically be notified of
 progress on your bug as I make changes.
 
+=head1 REPOSITORY
+
+L<https://git.framasoft.org/smonff/dependencies-searcher>
+
 =head1 TODOs
 
 Most of the time, todos and features are on Github and Questub.
@@ -881,7 +869,7 @@ See also :
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 smonff.
+Copyright 2013-2016 Sebastien Feugere.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
